@@ -96,6 +96,53 @@ static S_I little_main(shell_interaction & dialog, S_I argc, char * const argv[]
 	archive *cur = nullptr;
         dialog.set_beep(param.beep);
 
+#ifdef LIBDAR_NO_OPTIMIZATION
+
+	    // code added before release 2.5.11 for debugging
+	    // purposes. This will lead to new feature un 2.6.0
+
+	if(param.info_details
+	   && param.display_treated
+	   && param.display_skipped
+	   && param.display_finished)
+	{
+	    if(param.subtree != nullptr)
+	    {
+		string res = param.subtree->dump("    ");
+		dialog.warning("directory tree filter:");
+		dialog.warning(res);
+	    }
+
+	    if(param.selection != nullptr)
+	    {
+		string res = param.selection->dump("    ");
+		dialog.warning("filename filter:");
+		dialog.warning(res);
+	    }
+
+	    if(param.ea_mask != nullptr)
+	    {
+		string res = param.ea_mask->dump("    ");
+		dialog.warning("EA filter:");
+		dialog.warning(res);
+	    }
+
+	    if(param.compress_mask != nullptr)
+	    {
+		string res = param.compress_mask->dump("    ");
+		dialog.warning("Compression filter:");
+		dialog.warning(res);
+	    }
+
+	    if(param.backup_hook_mask != nullptr)
+	    {
+		string res = param.backup_hook_mask->dump("    ");
+		dialog.warning("backup hook filter:");
+		dialog.warning(res);
+	    }
+	}
+#endif
+
         if(param.filename != "-"
 	   || (param.output_pipe != "" && param.op != create && param.op != isolate && param.op != merging))
             dialog.change_non_interactive_output(&cout);
@@ -765,6 +812,7 @@ static S_I little_main(shell_interaction & dialog, S_I argc, char * const argv[]
 		read_options.set_slice_min_digits(param.num_digits);
 		read_options.set_ignore_signature_check_failure(param.blind_signatures);
 		read_options.set_multi_threaded(param.multi_threaded);
+		read_options.set_header_only(param.header_only);
 
 		arch = new (nothrow) archive(dialog,
 					     *param.sauv_root,
@@ -798,6 +846,7 @@ static S_I little_main(shell_interaction & dialog, S_I argc, char * const argv[]
 		    listing_options.set_display_ea(param.list_ea);
 		    if(!param.file_size.is_zero() && param.list_mode == archive_options_listing::slicing)
 			listing_options.set_user_slicing(param.first_file_size, param.file_size);
+		    listing_options.set_sizes_in_bytes(param.sizes_in_bytes);
 		    arch->op_listing(dialog, listing_options);
 		}
                 break;
