@@ -186,6 +186,8 @@ namespace libdar
 	    /// defines the protocol to use to retrieve slices of the reference archive (where the external catalogue resides)
 	void set_ref_entrepot(const entrepot & entr) { if(x_ref_entrepot != nullptr) delete x_ref_entrepot; x_ref_entrepot = entr.clone(); if(x_ref_entrepot == nullptr) throw Ememory("archive_options_read::set_entrepot"); };
 
+	    /// whether we only read the archive header and exit
+	void set_header_only(bool val) { x_header_only = val; };
 
 
 
@@ -217,6 +219,7 @@ namespace libdar
 	const std::string & get_ref_execute() const { return x_ref_execute; };
 	infinint get_ref_slice_min_digits() const { return x_ref_slice_min_digits; };
 	const entrepot & get_ref_entrepot() const { if(x_ref_entrepot == nullptr) throw SRC_BUG; return *x_ref_entrepot; };
+	bool get_header_only() const { return x_header_only; };
 
 
     private:
@@ -245,6 +248,7 @@ namespace libdar
 	std::string x_ref_execute;
 	infinint x_ref_slice_min_digits;
 	entrepot *x_ref_entrepot;
+	bool x_header_only;
 
 	void copy_from(const archive_options_read & ref);
 	void destroy();
@@ -1194,6 +1198,7 @@ namespace libdar
 	void set_filter_unsaved(bool filter_unsaved) { x_filter_unsaved = filter_unsaved; };
 	void set_display_ea(bool display_ea) { x_display_ea = display_ea; };
 	void set_user_slicing(const infinint & slicing_first, const infinint & slicing_others);
+	void set_sizes_in_bytes(bool arg) { x_sizes_in_bytes = arg; };
 
 	    /////////////////////////////////////////////////////////////////////
 	    // getting methods
@@ -1205,6 +1210,7 @@ namespace libdar
 	bool get_filter_unsaved() const { return x_filter_unsaved; };
 	bool get_display_ea() const { return x_display_ea; };
 	bool get_user_slicing(infinint & slicing_first, infinint & slicing_others) const;
+	bool get_sizes_in_bytes() const { return x_sizes_in_bytes; };
 
     private:
 	bool x_info_details;
@@ -1215,6 +1221,7 @@ namespace libdar
 	bool x_display_ea;
 	infinint *x_slicing_first;
 	infinint *x_slicing_others;
+	bool x_sizes_in_bytes;
 
 	void destroy();
 	void copy_from(const archive_options_listing & ref);
