@@ -46,20 +46,20 @@ extern "C"
 #include "cygwin_adapt.hpp"
 #include "shell_interaction.hpp"
 #include "crc.hpp"
-#include "fichier.hpp"
+#include "fichier_local.hpp"
 
 using namespace libdar;
 using namespace std;
 
-static user_interaction *ui = NULL;
+static user_interaction *ui = nullptr;
 
 int main(S_I argc, char *argv[])
 {
     U_I maj, med, min;
 
     get_version(maj, med, min);
-    ui = shell_interaction_init(&cout, &cerr, false);
-    if(ui == NULL)
+    ui = new (nothrow) shell_interaction(&cout, &cerr, false);
+    if(ui == nullptr)
 	cout << "ERREUR !" << endl;
 
     if(argc < 3)
@@ -68,25 +68,25 @@ int main(S_I argc, char *argv[])
         return -1;
     }
 
-    fichier f1 = fichier(*ui, argv[1], gf_read_only, tools_octal2int("0777"), false);
+    fichier_local f1 = fichier_local(*ui, argv[1], gf_read_only, 0, false, false, false);
     S_I fd = ::open(argv[2], O_WRONLY|O_CREAT|O_TRUNC|O_BINARY);
     if(fd < 0)
     {
         cout << "cannot open "<< argv[2] << endl;
         return -1;
     }
-    fichier f2 = fichier(*ui, fd);
+    fichier_local f2 = fichier_local(*ui, argv[2], gf_write_only, 0666, false, true, false);
 
     f1.reset_crc(crc::OLD_CRC_SIZE);
     f2.reset_crc(crc::OLD_CRC_SIZE);
     f1.copy_to(f2);
     crc *crc1 = f1.get_crc();
     crc *crc2 = f2.get_crc();
-    crc *crc3 = NULL;
+    crc *crc3 = nullptr;
 
     try
     {
-	if(crc1 == NULL || crc2 == NULL)
+	if(crc1 == nullptr || crc2 == nullptr)
 	    throw SRC_BUG;
 	if(*crc1 == *crc2)
 	    cout << "CRC OK" << endl;
@@ -95,31 +95,30 @@ int main(S_I argc, char *argv[])
 	f1.skip(0);
 	null_file f3 = null_file(gf_write_only);
 	f1.copy_to(f3, crc::OLD_CRC_SIZE, crc3);
-	if(crc3 == NULL)
+	if(crc3 == nullptr)
 	    throw SRC_BUG;
 	if(*crc1 == *crc3)
 	    cout << "CRC OK" << endl;
 	else
 	    cout << "CRC PROBLEM" << endl;
 
-	shell_interaction_close();
-	if(ui != NULL)
+	if(ui != nullptr)
 	    delete ui;
     }
     catch(...)
     {
-	if(crc1 != NULL)
+	if(crc1 != nullptr)
 	    delete crc1;
-	if(crc2 != NULL)
+	if(crc2 != nullptr)
 	    delete crc2;
-	if(crc3 != NULL)
+	if(crc3 != nullptr)
 	    delete crc3;
 	throw;
     }
-    if(crc1 != NULL)
+    if(crc1 != nullptr)
 	delete crc1;
-    if(crc2 != NULL)
+    if(crc2 != nullptr)
 	delete crc2;
-    if(crc3 != NULL)
+    if(crc3 != nullptr)
 	delete crc3;
 }
