@@ -72,7 +72,7 @@ void f1()
     libdar::compile_time::endian endy;
 
     get_version(maj, med, min);
-    printf("version %u.%u.%u\n", (unsigned int)maj, (unsigned int)med, (unsigned int)min);
+    ui.printf("version %u.%u.%u\n", maj, med, min);
     ea = libdar::compile_time::ea();
     large = libdar::compile_time::largefile();
     nodump = libdar::compile_time::nodump();
@@ -85,33 +85,34 @@ void f1()
     libcrypto = libdar::compile_time::libgcrypt();
     furtive = libdar::compile_time::furtive_read();
     endy = libdar::compile_time::system_endian();
-    printf("features:\nEA = %s\nLARGE = %s\nNODUMP = %s\nSPECIAL = %s\nbits = %u\nlibz =%s\nlibbz2 = %s\nliblzo = %s\nlibcrypto = %s\nfurtive = %s\nendian = %c\n",
-	   BOOL2STR(ea),
-	   BOOL2STR(large),
-	   BOOL2STR(nodump),
-	   BOOL2STR(special),
-	   (unsigned int)bits,
-	   BOOL2STR(libz),
-	   BOOL2STR(libbz2),
-	   BOOL2STR(liblzo2),
-	   BOOL2STR(libcrypto),
-	   BOOL2STR(furtive),
-	   endy);
+    ui.printf("features:\nEA = %s\nLARGE = %s\nNODUMP = %s\nSPECIAL = %s\nbits = %u\nthread = %s\nlibz =%s\nlibbz2 = %s\nliblzo = %s\nlibcrypto = %s\nfurtive = %s\nendian = %c\n",
+	      BOOL2STR(ea),
+	      BOOL2STR(large),
+	      BOOL2STR(nodump),
+	      BOOL2STR(special),
+	      bits,
+	      BOOL2STR(thread),
+	      BOOL2STR(libz),
+	      BOOL2STR(libbz2),
+	      BOOL2STR(liblzo2),
+	      BOOL2STR(libcrypto),
+	      BOOL2STR(furtive),
+	      endy);
 }
 
 void warning(const string &x, void *context)
 {
-    printf("[%ld]%s\n", (unsigned long int)context, x.c_str());
+    cout << "[" << context << "]" << x.c_str() << endl;
 }
 
 bool question(const string & x, void *context)
 {
     bool rep = false;
-	    char r;
+    char r;
 
-	    printf("[%p]%s\n", context, x.c_str());
-	    scanf("%c", &r);
-	    rep = r == 'y';
+    printf("[%p]%s\n", context, x.c_str());
+    scanf("%c", &r);
+    rep = r == 'y';
 
     return rep;
 }
@@ -163,7 +164,7 @@ void f2()
 	ui.printf("exception creating archive: %S\n", &msg);
 	return;
     }
-    if(toto != NULL)
+    if(toto != nullptr)
     {
 	archive_options_listing options;
 
@@ -197,9 +198,9 @@ void f2()
 	return;
     }
     if(ret)
-	printf("found children\n");
+	ui.printf("found children\n");
     else
-	printf("no found children\n");
+	ui.printf("no found children\n");
 
     ret = get_children_of_noexcept(ui, arch, "", code, msg);
     if(code != LIBDAR_NOEXCEPT)
@@ -208,9 +209,9 @@ void f2()
 	return;
     }
     if(ret)
-	printf("found children\n");
+	ui.printf("found children\n");
     else
-	printf("no found children\n");
+	ui.printf("no found children\n");
 
 
     close_archive_noexcept(arch, code, msg);
@@ -230,7 +231,7 @@ void f3()
     string msg;
     read_options.clear();
     read_options.set_info_details(true);
-    archive *arch = open_archive_noexcept(ui, ".", "titi", "dar", read_options, code, msg);
+    archive *arch = open_archive_noexcept(ui, ".", "toto", "dar", read_options, code, msg);
     if(code != LIBDAR_NOEXCEPT)
     {
 	ui.printf("exception openning archive: %S\n", &msg);
@@ -245,9 +246,9 @@ void f3()
 	return;
     }
     if(ret)
-	printf("found children\n");
+	ui.printf("found children\n");
     else
-	printf("no found children\n");
+	ui.printf("no found children\n");
 
     arch->init_catalogue(ui);
     vector<list_entry> contents = arch->get_children_in_table("etc");
@@ -287,6 +288,7 @@ void f4()
 	cancel_thread(tid);
 	fake.write("coucouc les amsi", 10);
 	ui.printf("this statement should never be reached\n");
+	ret = ret+1; // avoid warning of unused variable
     }
     catch(Egeneric & e)
     {
@@ -301,21 +303,10 @@ void f4()
 
 void f5()
 {
-    user_interaction *dialog = shell_interaction_init(&cout, &cerr, false);
+    string ret;
 
-    try
-    {
-	string ret;
-
-	ret = dialog->get_string("Mot de passe svp :", false);
-	cout << "---[" << ret << "]---" << endl;
-	ret = dialog->get_string("Mot de passe svp :", true);
-	cout << "---[" << ret << "]---" << endl;
-
-    }
-    catch(...)
-    {
-	delete dialog;
-	shell_interaction_close();
-    }
+    ret = ui.get_string("Mot de passe svp :", false);
+    cout << "---[" << ret << "]---" << endl;
+    ret = ui.get_string("Mot de passe svp :", true);
+    cout << "---[" << ret << "]---" << endl;
 }
